bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 28. Aventiure
___________________________________________________ #### <Wie Chrimhilt Hagen enphie>
| ### o die Burgonden komen in daz lant ### do gefriesch ez von Berne der halte Hyltebrant ### er seite ez sime herren ez was im harte leit ### er bat im wol enphahen die riter kvene <vn> gemeit
###### 1657 | ### Wolfart der snelle hiez bringen div march ### do reit mit Dietriche vil manich degen starch ### da er si gruozen wolde zvo in an daz velt [67b] ### da heten si ovf gebunden vil manic herlich gecelt
###### 1658 | ### Do si von Troni Hagne verrist riten sach ### zuo den sinen herren gezogenlich er sprach ### nu svlt ir snelle rechen von den sedele stan ### vn– get in hin enkegene die iuch da wellent hie enphan
###### 1659 | ### Dort kumet her ein gesinde daz ist mir wol bekant ### ez sint vil snelle degne von Amelunge lant ### <der> von Berne si fuort si sint vil hoch gemvot ### vn– lat iv niht versmahen swa man iv hie dienst tvot
###### 1660 | ### Do stvonden von den rossen daz waz michel reht ### neben Dyethriche manich ritter vnd kneht ### si giengen zvo den gesten da man die helde vant ### si grvosten minnecliche die von Bvrgonde lant
###### 1661 | ### Do si der herre Dyethriche gen im chomen sach ### hie mvget ir hoern gerne waz der degen sprach ### zvo den voten chinden ir reise waz im lait ### er wand ez weste Rvedeger daz er inz hete geseit
###### 1662 | ### Sit willechomen ir herren Gunther vn– Gyselher ### Gernot vn– Hagne sam si her Volker ### vn– Danchwart der snelle ist iv daz niht bechant ### Kriemhilt noch sere weinet den helt von Niblunge lant
###### 1663 | ### Si mach vil lange weinen sprach do Hagene ### er lit vor manigem iare ce tode erslagne ### den chvnich von den Hvnen sol si nv holden haben ### Sivrit chvmet niht widere er ist nv lange begraben
###### 1664 | ### Die Sifrides wunden lazzen wir nv sten ### sol leben vro ChriemhiIt so mach schade ergen ### so redete von Berne der herre Dyetriche ### troest der Niblung davor behvete dv dich
###### 1665 | ### Wie sol ich mich behveten sprach der kvenich her ### Ecel vns boten sande waz sold ich fragen mer ### daz wir zvo im solden riten in daz lant ### ovch hat vns manich mære mein swester Kriemhilt gesant
###### 1666 | ### Ich kan ev wol geraten sprach aber Hagne ### bittet iv div mære baz ze sagne ### den herren Dietrichen vnd seine helde gvot ### daz si iv lazen wizen der vrowen <Kriemhilt> muot
###### 1667 | ### Do giengen svndersprachen die dri kvnige riche ### Gvnther vn– Gernot vnd och her Dyetrich ### nu sag vns von Berne vil edel ritter gvot ### wie dir si gewizzen vmb der kvniginne mvot
###### 1668 | ### Do sprach der voit von Berne waz sol ich nv sagen ### ich hoere alle morgen weinen vnd klagen ### mit iæmerlichen sinnen daz Eceln wip ### dem richen gote von himel des starchen Sifrides lip
###### 1669 | ### Ez ist et vnerwendet sprach der chvene man ### Volker der videlare daz wir vernomen han ### wir svln ce hove riten vn– svln lazzen sehen ### waz vns snellen degen mvge cen Hvnen geschehen
###### 1670 | ### Die kvenen Bvrgonden hin ce hove riten [68a] ### si chomen herlichen nah ir landes siten ### do wunderte da cen Hvnen vil manigen kvenen man ### vmbe Hagnen von Trony wie der were getan
###### 1671 | ### Dvrch daz man seite mere dez waz im genvock ### daz er von Niderlanden Sifriden slvoch ### sterkest aller reken vrovn Kriemhilde man ### des wart michel vragen ce hove nah Hagen getan
###### 1672 | ### Der helt waz wol gewahsen daz ist al war ### groz waz er cen brusten gemischet waz sin har ### mit einer grisen varwe div bein warn im lanc ### eislich sin gesune er hete herlichen ganch
###### 1673 | ### Do hiez man herbergen die Burgonden man ### Gvnthers gesinde wart gesvndert dan ### daz riet div chvnigin div im vil hazes trvoch ### da von man sid die knehte an der herberge slvoch
###### 1674 | ### Dancwart Hagen brvoder der waz marschalch ### der chvnich im sin gesinde vliziclich bevalch ### daz er ir wol pflege vn– in gebe genvoch ### der helt von Bvrgonden in allen holden willen <trvoch>
###### 1675 | ### Kriemhilt div schoene mit ir gesinde gie ### da si die Niblunge mit valschem mvote enphie ### si kvste Gyselhern vn– nam in bi der hant ### daz sach von Trony Hagen den helm er vaster gebant
###### 1676 | ### Nach svs getanem grvoze so sprach Hagene ### mvgen sich verdenchen snelle degene ### man grvezet svnderlichen die kvnige vn– ir man ### wir haben niht gvoter reise zvo dirre hohzit getan
###### 1677 | ### Si sprach nv sit willekomen swem ivch gerne sihet ### dvrch iwer selbes vrivntschaft grveze ich ivch niht ### saget waz ir mir bringet von Wormz vber Rin ### darvmbe ir mir so groze soldet willechomen sin
###### 1678 | ### Waz sint disiv mere sprach do Hagene ### daz iv gabe solden bringen degne ### ich wesse ivch wol so riche ob ich mich baz kan verstan ### daz ich iv miner gabe her ze lande niht gefvert <han>
###### 1679 | ### Nv svlt ir mich <der> mære mere wizzen lan ### hort der Niblvnge war habet ir den getan ### der waz doch min eigen daz ist iv wol bechant ### den soldet ir mir bringen in daz Ecelen lant
###### 1680 | ### Entriwen min vrov Kriemhilt des ist manic tach ### daz ich der Niblunge hortes nie gepflach ### den hiezen min herren senken in den Rin ### da mvoz er werlichen vntz an daz ivngiste sin
###### 1681 | ### Do sprach div kvnigin ich hans och wol gedaht ### ir habet mirs noh vil wenich her ze lande braht ### swie er min eigen were vn– ich sin willent phlach ### des han ich zit vil swere vn– manigen trvrigen tach
###### 1682 | ### Ich bringe iv den tivel sprach Hagne [68b] ### ich han an mime schilde so vil ze tragne ### vn– an miner brvnne min helme der ist lieht ### daz swert an miner hende des enbringe ich ivh nicht
###### 1683 | ### Do sprach div kvniginne ze den reken vber al ### man sol deheiniv wafen tragen in den sal ### ir helde ir svlt mirs vfgeben ich wil si behalten lan ### entriwen sprach do Hagne daz wirdet nimmer getan
###### 1684 | ### Ja ger ich niht der eren fvrsten tohter milt ### daz ir ze den herbergen traget minen schilt ### vn– ander min gewæte ir sid ein kvnigin ### daz leret mich min vater niht ich wil selbe kamerere sin
###### 1685 | ### Owe miner leide sprach vrov Kriemhilt ### warvmbe wil min brvoder vn– Hagne sinen schilt ### niht lazen behalten si sint gewarnot ### vnde wesse ich wer daz tete ich riete im immer sinen tot
###### 1686 | ### Dez antwurte ir mit zorne der herre Dyethrich ### ich binz der hat gewarnt die edeln fvrsten riche ### vn– Hagnen den kvnen den Bvrgonden man ### nv zvo valadinne dv solt mihs niht geniezen lan
###### 1687 | ### Dez schamte sich vil sere daz Ecelen wip ### si vorhte bitterlichen Dyetrichs lip ### si gie von im balde daz si niht ensprach ### wan daz si swinde blicke an ir viende sach
###### 1688 | ### Bi henden sich do viengen zwene degne ### daz eine waz her Dyetrich daz ander Hagne ### do sprach gezogenlichen der reke vil gemeit ### iwer komen ze den Hvnen ist mir werlichen leit
###### 1689 | ### dvrch daz div kvnigine also gesprochen hat ### do sprach von Trony Hagne dez wirt wol allez rat ### svs reiten mit an ander die zwene kvene man ### daz sach der kvnich Ecel dar vmbe er vragen began
###### 1690 | ### Div mere ich weste gerne sprach der kvnic rich ### wer iener reke were den dort her Dyetrich ### so vrivntlich enpfahet er treit vil hohen mvot ### swer sin vater were er mach wol sin ein reche gvot
###### 1691 | ### Dez antwurte dem kvnige ein Kriemhilde man ### er ist geborn von Trony sin vater hiez Aldrian ### swie blide er hie gebare er ist ein grimmich man ### ich laze ivch daz beschowen daz ich gelogen niene han
###### 1692 | ### Wie sol ich daz erchennen daz er so grimmich ist ### dannoh er niht weste so manigen argen list ### den sid div kvnigin an ir magen begie ### daz si ir nie deheinen von den Hvnen komen lie
###### 1693 | ### Wol erchand ich Aldrianen wan er waz min man ### lop vn– michel ere er hie bi ir gewan ### ich machte in ze rittere vn– gap im min golt ### dvrh daz er getriv waz des mvoz im wesen ich holt
###### 1694 | ### Da von ich wol erkenne allez Hagnen sint ### ez warn wol zwei weitlichiv kint [69a] ### er vn– von Spane Walther die wuohsen hie ze man ### Hagen sand ich wider haim Walther mit Hiltegvnde entran
###### 1695 | ### Er dahte lieber mere div warn e geschehen ### sinen vrivnt von Trony hete er rehte ersehen ### der im in siner ivgende vil starkiv dienst bot ### sid frvmter im in alter vil manigen lieben vrivnt tot

<<< Übersicht <<< vorige Seite nächste Seite >>>